@@ -33,17 +33,11 @@
 
 class AiExample : public ComputerPlayer
 {
-    Q_OBJECT
-
 public:
     explicit AiExample(Game *game, const QString &newName, const QColor &color);
 
     virtual void play();
 
-signals:
-
-public slots:
-
 };
 
 #endif // AI_EXAMPLE_H
